*******************************************
Verificator for GROGU spin Hamiltonian file
*******************************************

To verify the spin Hamiltonian file:

*   (optional) Create virtual environment

    .. code-block:: console

        python3.13 -m venv .venv


*   (optional) Activate virtual environment

    .. code-block:: console

        source .venv/bin/activate

*   Install the tool

    .. code-block:: console

        pip install vegrofi

*   Run the Verificator

    .. code-block:: console

        vegrofi <filename>

* Enjoy
